#!/usr/bin/perl

# simple script to generate formatted list of SNCL, lat, lon, elev, sample_rate
# This list needs to be very generous; otherwise merge_was_stn_eq_data dies if it
# can't find a SNCL. So there appears to be little advantage to make the
# start and end dates or network list into command-line options.

use strict;
use DBI;

# Global variables
our ( $VERSION, $cmdname, $bbThresh);
our ( $minDate, $maxDate, @nets );
our ( $dbName, $dbUser, $dbPass, $dbh );

$VERSION = "1.02 (2021/08/04)";
$dbName = "publicdb";
$dbUser = "browser";
$dbPass = "readonly";

@nets = ('AZ','BG','BK','CE','CI','GM','GS','LB','US','NC','NN','NP','PG','SB','TA',
	 'UO','UW', 'WR');
$minDate = '2007-01-01';
$maxDate = '2022-08-01';

exit main();

sub main {

    if (@ARGV && $ARGV[0] == '-h') {
	print STDERR "Usage: $0\n";
	exit 0;
    }

    my %nets;
    foreach my $net (@nets) {
	$nets{$net} = 1;
    }

    eval {
	$dbh = DBI->connect("dbi:Oracle:" . $dbName, $dbUser, $dbPass,
			    {RaiseError => 1,
			     PrintError => 0,
			     AutoCommit => 0});

	# The REMAINDER function below gets azimuth within +/-2 degrees of cardinal dirs:
	# removed since merge_was_stn_eq_data fails with missing SNCLs
	# AND c.dip = 0 AND remainder(c.azimuth + 5, 90) between 3 and 7	
	my $sth = $dbh->prepare(qq{
           SELECT UNIQUE c.sta, c.net, c.seedchan, c.location, c.lat, c.lon, c.elev, c.samprate
           FROM channel_data c, simple_response r
           WHERE c.sta = r.sta and c.net = r.net and c.seedchan = r.seedchan
           AND c.location = r.location AND c.ondate = r.ondate
           AND c.samprate >= 20 AND r.gain_units in ('DU/M/S', 'DU/M/S**2')
           AND c.dip = 0
           AND (c.ondate < to_date(:dend, 'YYYY-MM-DD')
           OR c.offdate > to_date(:dstart, 'YYYY-MM-DD'))
           ORDER BY c.net, c.sta, c.seedchan, c.location});
	$sth->bind_param(":dstart", $minDate);
	$sth->bind_param(":dend", $maxDate);
	$sth->execute();
	my $aryref = $sth->fetchall_arrayref({});
	die "No data found\n" unless (0 < scalar @$aryref);

	foreach my $ref (@$aryref) {
	    my $net = $ref->{NET};
	    next unless (exists $nets{$net});
	    my $sta = $ref->{STA};
	    my $chan = $ref->{SEEDCHAN};
	    my $loc = $ref->{LOCATION};
	    $loc =~ s/\s/-/g;
	    my $lat = $ref->{LAT};
	    my $lon = $ref->{LON};
	    my $elev = $ref->{ELEV};
	    my $sr = $ref->{SAMPRATE};

#ADO  CI HHE -- 34.55046 -117.43391   908  100
#SSSS NN CCC LL ll.lllll LLLL.lllll EEEEE RRRR
#012345678901234567890123456789012345678901234
#0         1         2         3         4

	    printf "%-4s %2s %3s %2s %8.5f %10.5f %5d %4d\n", $sta, $net, $chan, $loc,
	    $lat, $lon, $elev, $sr;
	}
    };
    if ($@) {
	print STDERR "error $@\n";
    }
    $dbh->disconnect() if $dbh;

    return;
}
